#!/bin/sh

# SEQUOIA_HOME definition
if [ -z "$SEQUOIA_HOME" ] ; then 
  echo "Cannot find Sequoia home directory. Please set the SEQUOIA_HOME environment variable."
  exit 1
fi

# JAVA setup.
#
# We try to use first the java JVM in JAVA_HOME and if not found,
# we use the one found in the path.
# You can specify additional options to give to the Java JVM in the
# JVM_OPTIONS environment variable.
if [ -z "$JAVA_HOME" ]
then
    JAVA=`which java`
    if [ ! -x "$JAVA" ]; then
      echo "Cannot find java command. Please set the JAVA_HOME environment variable."
      exit 1
    fi
else
    JAVA=$JAVA_HOME/bin/java
fi
export JAVA

[ -z "$HSQL_HOME" ] && HSQL_HOME=$SEQUOIA_HOME/3rdparty/hsqldb
  
[ -z "$ISQL_HOME" ] && ISQL_HOME=$SEQUOIA_HOME/3rdparty/iSQL
  
[ -z "$SEQUOIA_DEFAULT_JVMDEBUG_PORT" ] && SEQUOIA_DEFAULT_JVMDEBUG_PORT=52002
  

# swallow option not yet implemented
[ "$1" != "nobg" ] || shift

# IPv6 is untested
JVM_OPTIONS="-Djava.net.preferIPv4Stack=true ${JVM_OPTIONS}"

# Environment variables for OptimizeIt
# export LD_LIBRARY_PATH=/home/emmanuel/OptimizeitEntSuite60/lib/:$LD_LIBRARY_PATH
# export PATH=/home/emmanuel/OptimizeitEntSuite60/lib/:$PATH

# uncomment to debug
# JVM_OPTIONS="${JVM_OPTIONS} -enableassertions -Xdebug -Xnoagent -Djava.compiler=none -Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=$SEQUOIA_DEFAULT_JVMDEBUG_PORT"
  
# Set the classpath.
unset CLASSPATH
CLASSPATH=:$SEQUOIA_HOME/drivers/sequoia-driver.jar:$ISQL_HOME/lib/bsf.jar:$ISQL_HOME/lib/isql-core.jar:$ISQL_HOME/lib/jpython1.1.jar:$ISQL_HOME/lib/lax.jar:$ISQL_HOME/lib/mozilla-rhino:$HSQL_HOME/lib/hsqldb.jar:$CLASSPATH_XTRA


# Change directory if needed
cd $ISQL_HOME

# Java Command.
$JAVA -classpath $CLASSPATH  $JVM_OPTIONS com.zerog.lax.LAX iSQL-Viewer.lax  "$@"
